LinchPin
--------

LinchPin provides a command-line interface and Python API for provisioning and
managing resources across multiple infrastructures. Where multiple
infrastructure resource types can be defined with a single topology file.

LinchPin can also generate inventory files for use with additional Ansible
playbooks. These are applied using an inventory layout file.

Contributing and Community Participation
++++++++++++++++++++++++++++++++++++++++

Developers are encouraged to contribute to the LinchPin project. Please visit
`Contributing <http://github.com/CentOS-PaaS-SIG/linchpin/tree/develop/CONTRIBUTING.rst>`_
for details.

* Subscribe and participate on the `LinchPin Mailing List <https://www.redhat.com/mailman/listinfo/linchpin>`_
* Join the `#linchpin` IRC chat channel on `freenode <https://webchat.freenode.net/?channels=#linchpin>`_

Installation
++++++++++++

`Installation documentation <http://linchpin.readthedocs.io/en/develop/installation.html>`_

QuickStart
++++++++++

The `Getting Started Guide <http://linchpin.readthedocs.io/en/develop/getting_started.html>`_ is a quick guide for LinchPin from the Command-Line.

General Configuration
+++++++++++++++++++++

`General Configuration documentation <http://linchpin.readthedocs.io/en/latest/config_general.html>`_

Example Topologies
+++++++++++++++++++++

`Example Topologies <http://linchpin.readthedocs.io/en/latest/topologies.html>`_

Example Inventory Layout (openshift 3 node cluster)
+++++++++++++++++++++++++++++++++++++++++++++++++++

`Example Layouts <http://linchpin.readthedocs.io/en/latest/config_layout.html>`_

Using LinchPin
+++++++++++++++

Check out the `Getting Started Guide <http://linchpin.readthedocs.io/en/develop/getting_started.html>`_ for a quick guide on how to use LinchPin from the Command-Line.

For API documentation, check out the `Python API Reference <http://linchpin.readthedocs.io/en/develop/libdocs.html>`_.

